
Usage
======

.. highlight:: bash


Command Operation.

New
---------

::

    $ python manage.py generate spine:new your_app


Scaffold
---------

::

    $ python manage.py generate spine:scaffold your_app example name content message


Model
-------

::


    $ python manage.py generate spine:model your_app example name content message



Controller
------------

::

    $ python manage.py generate spine:model your_app




Help
------------

For more information, please run the below.

::

    $ python manage.py generate -h
    $ python manage.py generate spine:new -h
    $ python manage.py generate spine:scaffold -h


